@@ -23,6 +23,7 @@ class AudioCD(CD):
 
     @CD.max_size.getter
     def max_size(self) -> float:
+        # 80 minutes of audio in seconds
         return 80 * 60
 
     @override
@@ -33,6 +34,10 @@ class AudioCD(CD):
     def get_tracks(self):
         return self._tracks
 
+    @override
+    def is_empty(self) -> bool:
+        return len(self._tracks) == 0
+
     @override
     def numberize(self):
         track_count = len(self._tracks)
